PrettyTextField class

A Calculator.

Inheritance

Constructors

PrettyTextField({Key? key, dynamic labelText, dynamic width, dynamic autocorrect, dynamic autofillHints, dynamic autofocus, dynamic buildCounter, dynamic clipBehavior, dynamic cursorColor, dynamic cursorHeight, dynamic cursorWidth, dynamic cursorRadius, dynamic dragStartBehavior, dynamic enabled, dynamic enableIMEPersonalizedLearning, dynamic enableInteractiveSelection, dynamic enableSuggestions, dynamic expands, dynamic focusNode, dynamic inputFormatters, dynamic keyboardAppearance, dynamic keyboardType, dynamic maxLength, dynamic maxLengthEnforcement, dynamic maxLines, dynamic minLines, dynamic mouseCursor, dynamic obscureText, dynamic obscuringCharacter, dynamic onAppPrivateCommand, dynamic onChanged, dynamic onEditingComplete, dynamic onSubmitted, dynamic onTap, dynamic scrollPadding, dynamic scrollPhysics, dynamic showCursor, dynamic strutStyle, dynamic style, dynamic textAlignVertical, dynamic textInputAction, dynamic textDirection, dynamic toolbarOptions, dynamic textAlign})

Properties

autocorrect → dynamic
final
autofillHints → dynamic
final
autofocus → dynamic
final
buildCounter → dynamic
final
clipBehavior → dynamic
final
controller TextEditingController
final
cursorColor → dynamic
final
cursorHeight → dynamic
final
cursorRadius → dynamic
final
cursorWidth → dynamic
final
dragStartBehavior → dynamic
final
enabled → dynamic
final
enableIMEPersonalizedLearning → dynamic
final
enableInteractiveSelection → dynamic
final
enableSuggestions → dynamic
final
expands → dynamic
final
focusNode → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
inputFormatters → dynamic
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardAppearance → dynamic
final
keyboardType → dynamic
final
labelText → dynamic
final
maxLength → dynamic
final
maxLengthEnforcement → dynamic
final
maxLines → dynamic
final
minLines → dynamic
final
mouseCursor → dynamic
final
obscureText → dynamic
final
obscuringCharacter → dynamic
final
onAppPrivateCommand → dynamic
final
onChanged → dynamic
final
onEditingComplete → dynamic
final
onSubmitted → dynamic
final
onTap → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollPadding → dynamic
final
scrollPhysics → dynamic
final
showCursor → dynamic
final
strutStyle → dynamic
final
style → dynamic
final
textAlign → dynamic
final
textAlignVertical → dynamic
final
textDirection → dynamic
final
textInputAction → dynamic
final
toolbarOptions → dynamic
final
width → dynamic
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<PrettyTextField>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited